@@ -3,7 +3,7 @@ use crate::prelude::*;
 
 /// Bass boost filter attribute
 #[repr(u32)]
-#[derive(FilterAttr, Copy, Clone, Debug, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, Debug, PartialOrd, PartialEq)]
 pub enum BassBoostFilterAttr {
     /// Wet attribute
     Wet = 0,
@@ -12,16 +12,19 @@ pub enum BassBoostFilterAttr {
 }
 
 /// Bass boost filter
-#[derive(Debug, FilterExt)]
+#[derive(Debug)]
 pub struct BassboostFilter {
-    _inner: *mut soloud_sys::soloud::BassboostFilter,
+    inner: *mut soloud_sys::soloud::BassboostFilter,
 }
 
+crate::macros::filter::impl_filter_ext!(BassboostFilter);
+crate::macros::filter::impl_filter_type!(BassBoostFilterAttr);
+
 impl BassboostFilter {
     /// Set filter params
     pub fn set_params(&mut self, delay: f32) -> Result<(), SoloudError> {
         ffi_call!(soloud_sys::soloud::BassboostFilter_setParams(
-            self._inner,
+            self.inner,
             delay
         ))
     }
