@@ -3,7 +3,7 @@ use crate::prelude::*;
 
 /// Flanger filter attributes
 #[repr(u32)]
-#[derive(FilterAttr, Copy, Clone, Debug, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, Debug, PartialOrd, PartialEq)]
 pub enum FlangerFilterAttr {
     /// Wet attribute
     Wet = 0,
@@ -14,16 +14,19 @@ pub enum FlangerFilterAttr {
 }
 
 /// Flanger filter
-#[derive(Debug, FilterExt)]
+#[derive(Debug)]
 pub struct FlangerFilter {
-    _inner: *mut soloud_sys::soloud::FlangerFilter,
+    inner: *mut soloud_sys::soloud::FlangerFilter,
 }
 
+crate::macros::filter::impl_filter_ext!(FlangerFilter);
+crate::macros::filter::impl_filter_type!(FlangerFilterAttr);
+
 impl FlangerFilter {
     /// Set filter params
     pub fn set_params(&mut self, delay: f32, freq: f32) -> Result<(), SoloudError> {
         ffi_call!(soloud_sys::soloud::FlangerFilter_setParams(
-            self._inner,
+            self.inner,
             delay,
             freq
         ))
