@@ -3,7 +3,7 @@ use crate::prelude::*;
 
 /// Lofi filter attributes
 #[repr(u32)]
-#[derive(FilterAttr, Copy, Clone, Debug, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, Debug, PartialOrd, PartialEq)]
 pub enum LofiFilterAttr {
     /// Wet attribute
     Wet = 0,
@@ -14,16 +14,19 @@ pub enum LofiFilterAttr {
 }
 
 /// Lofi filter
-#[derive(Debug, FilterExt)]
+#[derive(Debug)]
 pub struct LofiFilter {
-    _inner: *mut soloud_sys::soloud::LofiFilter,
+    inner: *mut soloud_sys::soloud::LofiFilter,
 }
 
+crate::macros::filter::impl_filter_ext!(LofiFilter);
+crate::macros::filter::impl_filter_type!(LofiFilterAttr);
+
 impl LofiFilter {
     /// Set filter params
     pub fn set_params(&mut self, samplerate: f32, bit_depth: f32) -> Result<(), SoloudError> {
         ffi_call!(soloud_sys::soloud::LofiFilter_setParams(
-            self._inner,
+            self.inner,
             samplerate,
             bit_depth
         ))
