@@ -3,7 +3,7 @@ use crate::prelude::*;
 
 /// Wave shaper filter attributes
 #[repr(u32)]
-#[derive(FilterAttr, Copy, Clone, Debug, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, Debug, PartialOrd, PartialEq)]
 pub enum WaveShaperFilterAttr {
     /// "Wet" attribute
     Wet = 0,
@@ -12,16 +12,19 @@ pub enum WaveShaperFilterAttr {
 }
 
 /// Wrapper around the wave shaper filter
-#[derive(Debug, FilterExt)]
+#[derive(Debug)]
 pub struct WaveShaperFilter {
-    _inner: *mut soloud_sys::soloud::WaveShaperFilter,
+    inner: *mut soloud_sys::soloud::WaveShaperFilter,
 }
 
+crate::macros::filter::impl_filter_ext!(WaveShaperFilter);
+crate::macros::filter::impl_filter_type!(WaveShaperFilterAttr);
+
 impl WaveShaperFilter {
     /// Set filter params
     pub fn set_params(&mut self, amount: f32) -> Result<(), SoloudError> {
         ffi_call!(soloud_sys::soloud::WaveShaperFilter_setParams(
-            self._inner,
+            self.inner,
             amount
         ))
     }
